#!/bin/bash -norc
set -x

TOP=/usr/local/fist
$TOP/sbin/fist_ioctl /mnt/cryptfs ${1:-18}

mkdir /mnt/cryptfs/a.$$
read n
rmdir /mnt/cryptfs/a.$$

exit

cd /mnt/cryptfs/am-utils-6.0b2s3/A.i586-pc-linux-gnu/amq
strace as -V -Qy -o amq.o amq.s 2>&1
read n
nm amq.o
exit


# strace grep foo /mnt/cryptfs/X-26
# read n
# cmp /n/fist/ext2fs/X-26 /mnt/cryptfs/X-26
# exit

# n=40
# while test $n -gt 0 ; do
#     strace grep foo /mnt/cryptfs/X-$n > /n/fist/ext2fs/log-$n.txt 2>&1
#     cmp /n/fist/ext2fs/X-$n /mnt/cryptfs/X-$n && echo "	SAME: /n/fist/ext2fs/X-$n /mnt/cryptfs/X-$n"
#     let n=n-1
# done

#strace grep foo /mnt/cryptfs/config.cache
#strace /usr/local/gnu/bin/grep foo /mnt/cryptfs/config.cache
#sed s/foo/bar/g < /mnt/cryptfs/config.cache > /dev/null
#cut -d0 -f1 /mnt/cryptfs/config.cache > /dev/null
#read n
#cmp  /mnt/cryptfs/config.cache ${HOME}/config.cache
exit

read n
head /mnt/cryptfs/config.cache

#read n
#cp -p ${HOME}/config.cache /mnt/cryptfs
